var TcoAuthFunctions = function(ScreenService, MessageService) {

    /**
     * Check if there is an exception that
     * come from TcoAuthentication Backend.
     * 
     * @param {String} responseData 
     * @param {String} url 
     */
    var tcoAuthExceptionHandler = function(responseData, url) {
        if (url) {
            try {
                var responseObj = JSON.parse(responseData);
                var errorCode = responseObj.error;

                if (errorCode && errorCode.indexOf('TCOAUTH_') > -1) {
                    MessageService.showMessageByCode(errorCode)
                        .then(() => {
                            exceptionHandlerFunctions[errorCode]();
                        });
                }
            } catch (e) {
                return false;
            }
        }
    };

    /**
     * Redirect user for dashboard if is
     * a invalid system user.
     */
    var invalidUserExceptionHandler = function() {
        var productInitUrl = window.metadataUrls.filter(urlObj => urlObj.package == 'product')[0].baseUrl;
        productInitUrl = productInitUrl.replace('assets/', '');

        window.location.replace(productInitUrl);
    };

    /**
     * Object that points functions to be
     * called after exception handler message,
     * according to the error code.
     */
    var exceptionHandlerFunctions = {
        'TCOAUTH_INVALID_USER': invalidUserExceptionHandler
    };

    /**
     * Object that points functions to be
     * called default.
     */
    this.defaultFunctions = [
        tcoAuthExceptionHandler
    ];

    /**
     * Object that points a function to
     * be executed when a backend route
     * is called.
     */
    this.functionByRoute = {};
};
